@@ -10,42 +10,31 @@ require Exporter;
 use AutoLoader;
 use Crypt::OpenSSL::EC;
 use Crypt::OpenSSL::Bignum;
+use Crypt::OpenSSL::Base::Func;
 use Math::BigInt;
-use Math::BigRat;
 use POSIX;
 #use Data::Dump qw/dump/;
 
-our $VERSION = '0.022';
+our $VERSION = '0.03';
 
 our @ISA = qw(Exporter);
 
 our @EXPORT = qw(
-  OBJ_sn2nid
-  EVP_MD_size
-  EVP_MD_block_size
-  EVP_get_digestbyname
-  EC_POINT_point2hex
-  EC_POINT_hex2point
-  EC_GROUP_get_curve
-  EC_POINT_set_affine_coordinates
-  EC_POINT_get_affine_coordinates
-  EC_POINT_point2hex
-  EC_POINT_hex2point
-
   sgn0_m_eq_1
+  clear_cofactor
+  CMOV
+
   calc_c1_c2_for_sswu
   map_to_curve_sswu_not_straight_line
   map_to_curve_sswu_straight_line
+
+  sn2z
   get_hash2curve_params
+  expand_message_xmd
+  hash_to_field
   map_to_curve
   encode_to_curve
   hash_to_curve
-  clear_cofactor
-  digest
-  hash_to_field
-  expand_message_xmd
-  sn2z
-  hex2point
 );
 
 our @EXPORT_OK = @EXPORT;
